pub struct Nick(pub String);Expand description
Represents a global, memorable, friendly or informal name chosen by a user.
Tuple Fields
0: StringTrait Implementations
Sourceimpl AsXml for Nick
impl AsXml for Nick
Sourcetype ItemIter<'xso_proc_as_xml_iter_lifetime> = NickAsXmlIterator<'xso_proc_as_xml_iter_lifetime>
where
Self: 'xso_proc_as_xml_iter_lifetime
type ItemIter<'xso_proc_as_xml_iter_lifetime> = NickAsXmlIterator<'xso_proc_as_xml_iter_lifetime> where Self: 'xso_proc_as_xml_iter_lifetime
The iterator type. Read more
impl Eq for Nick
Sourceimpl FromXml for Nick
impl FromXml for Nick
Sourcefn from_events(
name: QName,
attrs: AttrMap,
ctx: &Context<'_>,
) -> Result<Self::Builder, FromEventsError>
fn from_events( name: QName, attrs: AttrMap, ctx: &Context<'_>, ) -> Result<Self::Builder, FromEventsError>
Attempt to initiate the streamed construction of this struct from XML. Read more
Sourcefn xml_name_matcher() -> XmlNameMatcher<'static>
fn xml_name_matcher() -> XmlNameMatcher<'static>
Return a predicate which determines if
Self may be parsed from
a given XML element. Read moreimpl StructuralPartialEq for Nick